/*
 / _____)             _              | |
( (____  _____ ____ _| |_ _____  ____| |__
 \____ \| ___ |    (_   _) ___ |/ ___)  _ \
 _____) ) ____| | | || |_| ____( (___| | | |
(______/|_____)_|_|_| \__)_____)\____)_| |_|
    (C)2015 Semtech

Description: End device commissioning parameters

License: Revised BSD License, see LICENSE.TXT file include in the project

Maintainer: Miguel Luis and Gregory Cristian
*/
#ifndef __LORA_COMMISSIONING_H__
#define __LORA_COMMISSIONING_H__

/**
 * When set to 1 the application uses the Over-the-Air activation procedure
 * When set to 0 the application uses the Personalization activation procedure
 */
#define OVER_THE_AIR_ACTIVATION     0

/**@breif Indicates if the end-device is to be connected to a private or public network
 */
#define LORAWAN_PUBLIC_NETWORK      true

/**
 * When set to 1 DevEui is LORAWAN_DEVICE_EUI
 * When set to 0 DevEui is automatically generated by calling BoardGetUniqueId function
 */
#define STATIC_DEVICE_EUI           1

/**@brief Mote device IEEE EUI (big endian)
 *
 * @remark see STATIC_DEVICE_EUI comments
 */
//#define LORAWAN_DEVICE_EUI          {0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 00}
#define LORAWAN_DEVICE_EUI          {0xA2, 0x3C, 0x78, 0xFF, 0xA7, 0x68, 0xCD, 0x02} 

/**@brief Application IEEE EUI (big endian)
 */
//#define LORAWAN_APPLICATION_EUI     {0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 00}
#define LORAWAN_APPLICATION_EUI     {0xA2, 0x3C, 0x78, 0xFF, 0xA7, 0x68, 0xCD, 0xB3} 
						
/**@brief AES encryption/decryption cipher application key
 */
#define LORAWAN_APPLICATION_KEY     {0x2B, 0x7E, 0x15, 0x16, 0x28, 0xAE, 0xD2, 0xA6, 0xAB, 0xF7, 0x15, 0x88, 0x09, 0xCF, 0x4F, 0x3C}

/**@brief Current network ID
 */
#define LORAWAN_NETWORK_ID          (uint32_t)0

/**
 * When set to 1 DevAdd is LORAWAN_DEVICE_ADDRESS
 * When set to 0 DevAdd is automatically generated using
 *         a pseudo random generator seeded with a value derived from
 *         BoardUniqueId value
 */
#define STATIC_DEVICE_ADDRESS       1

/**@brief Device address on the network (big endian)
 *
 * @remark In this application the value is automatically generated using
 *         a pseudo random generator seeded with a value derived from
 *         BoardUniqueId value if LORAWAN_DEVICE_ADDRESS is set to 0
 */
#define LORAWAN_DEVICE_ADDRESS      (uint32_t)0x00000002

/**@brief AES encryption/decryption cipher network session key
 */
//#define LORAWAN_NWKSKEY             {0x2B, 0x7E, 0x15, 0x16, 0x28, 0xAE, 0xD2, 0xA6, 0xAB, 0xF7, 0x15, 0x88, 0x09, 0xCF, 0x4F, 0x3C}
#define LORAWAN_NWKSKEY             {0x16, 0x44, 0x01, 0x0B, 0xFA, 0x2D, 0x45, 0xF3, 0xA2, 0x57, 0xC6, 0x70, 0x26, 0xAD, 0x74, 0xF3}

/**@brief AES encryption/decryption cipher application session key
 */
//#define LORAWAN_APPSKEY             {0x2B, 0x7E, 0x15, 0x16, 0x28, 0xAE, 0xD2, 0xA6, 0xAB, 0xF7, 0x15, 0x88, 0x09, 0xCF, 0x4F, 0x3C}
#define LORAWAN_APPSKEY             {0x16, 0x44, 0x01, 0x0B, 0xFA, 0x2D, 0x45, 0xF3, 0xA2, 0x57, 0xC6, 0x70, 0x26, 0xAD, 0x74, 0xF3}

#endif // __LORA_COMMISSIONING_H__
